﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Controls.Menus;

namespace DataTreeSelectionWidth
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public static double GetIndentation(DependencyObject obj)
        {
            return (double)obj.GetValue(IndentationProperty);
        }

        public static void SetIndentation(DependencyObject obj, double value)
        {
            obj.SetValue(IndentationProperty, value);
        }

        // Using a DependencyProperty as the backing store for Indentation.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty IndentationProperty =
            DependencyProperty.RegisterAttached("Indentation", typeof(double), typeof(MainWindow), new PropertyMetadata(0.0));

        public MainWindow()
        {
            InitializeComponent();

            //
        }

        private void MyTree_DataContextChanged(object sender, DependencyPropertyChangedEventArgs e)
        {

        }

        private void Window_DataContextChanged(object sender, DependencyPropertyChangedEventArgs e)
        {

        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            
        }

        private void MyTree_Loaded(object sender, RoutedEventArgs e)
        {
            MyTree.Nodes[2].IsSelected = true;
            MyTree.Nodes[2].IsExpanded = true;
        }

        private void OnNodeClicked(object sender, RoutedEventArgs e)
        {
            XamDataTreeNodeControl control = sender as XamDataTreeNodeControl;
            XamDataTreeNodeDataContext dc = control.DataContext as XamDataTreeNodeDataContext;
            dc.Node.IsSelected = true;
        }
    }

    public class SampleData : ObservableCollection<ParentNode>
    {
        public SampleData()
        {
            ParentNode p1 = new ParentNode { Name = "Profitability", Children = new ObservableCollection<ChildNode>() };
            ParentNode p2 = new ParentNode { Name = "Growth", Children = new ObservableCollection<ChildNode>() };
            ParentNode p3 = new ParentNode { Name = "Efficiency", Children = new ObservableCollection<ChildNode>() };
            ParentNode p4 = new ParentNode { Name = "Investment", Children = new ObservableCollection<ChildNode>() };
            ParentNode p5 = new ParentNode { Name = "Capital Strength", Children = new ObservableCollection<ChildNode>() };
            ParentNode p6 = new ParentNode { Name = "Quality", Children = new ObservableCollection<ChildNode>() };

            p1.Children.Add(new ChildNode());
            p2.Children.Add(new ChildNode());
            p4.Children.Add(new ChildNode());
            p5.Children.Add(new ChildNode());
            p6.Children.Add(new ChildNode());

            Stats stat = new Stats() { Value = 1, Average = 64.3, StandardDeviation = 32.6, Percent = 1.0 };
            ObservableCollection<Stats> statColl = new ObservableCollection<Stats>();//.Add(stat);
            statColl.Add(stat);
            p3.Children.Add(new ChildNode { Name = "Days sales outstanding", Stats = statColl });
            p3.Children.Add(new ChildNode { Name = "Days payables outstanding", Stats = statColl });
            p3.Children.Add(new ChildNode { Name = "Inventory turnover, days", Stats = statColl });
            p3.Children.Add(new ChildNode { Name = "NWI / Sales", Stats = statColl });
            p3.Children.Add(new ChildNode { Name = "Asset turnover", Stats = statColl });

            this.Add(p1);
            this.Add(p2);
            this.Add(p3);
            this.Add(p4);
            this.Add(p5);
            this.Add(p6);
        }
    }

    public class ParentNode
    {
        public string Name { get; set; }

        public ObservableCollection<ChildNode> Children { get; set; }
    }

    public class ChildNode
    {
        public string Name { get; set; }
        public string Description { get; set; }
        public ObservableCollection<Stats> Stats { get; set; }
    }


    public class Stats
    {
        public string Name { get; set; }

        public double Value { get; set; }

        public double Average { get; set; }

        public double StandardDeviation { get; set; }

        public double Percent { get; set; }

        public Stats()
        {
            Name = "";
        }
    }

    public class NodeWidthCalculator : IMultiValueConverter
    {
        public object Convert(object[] values, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            if (values[0] == DependencyProperty.UnsetValue || values[1] == DependencyProperty.UnsetValue)
                return 0;

            int level = (int)values[0];
            double indentation = (double)values[1];

            return level * indentation;
        }

        public object[] ConvertBack(object value, Type[] targetTypes, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
}
